@@ -8,11 +8,14 @@ use Dancer::Plugin::DBIC;
 use Socket6 (); # to ensure dependency is met
 use HTML::Entities (); # to ensure dependency is met
 use URI::QueryParam (); # part of URI, to add helper methods
+use Path::Class 'dir';
 
 use App::Netdisco::Web::AuthN;
+use App::Netdisco::Web::Static;
 use App::Netdisco::Web::Search;
 use App::Netdisco::Web::Device;
 use App::Netdisco::Web::Report;
+use App::Netdisco::Web::AdminTask;
 use App::Netdisco::Web::TypeAhead;
 use App::Netdisco::Web::PortControl;
 
@@ -20,8 +23,9 @@ sub _load_web_plugins {
   my $plugin_list = shift;
 
   foreach my $plugin (@$plugin_list) {
+      $plugin =~ s/^X::/+App::NetdiscoX::Web::Plugin::/;
       $plugin = 'App::Netdisco::Web::Plugin::'. $plugin
-        unless $plugin =~ m/^\+/;
+        if $plugin !~ m/^\+/;
       $plugin =~ s/^\+//;
 
       debug "loading Netdisco plugin $plugin";
@@ -35,6 +39,7 @@ if (setting('web_plugins') and ref [] eq ref setting('web_plugins')) {
 }
 
 if (setting('extra_web_plugins') and ref [] eq ref setting('extra_web_plugins')) {
+    unshift @INC, dir(($ENV{NETDISCO_HOME} || $ENV{HOME}), 'site_plugins')->stringify;
     _load_web_plugins( setting('extra_web_plugins') );
 }
 
@@ -50,9 +55,18 @@ hook 'before_template' => sub {
 
     # allow very long lists of ports
     $Template::Directive::WHILE_MAX = 10_000;
+
+    # allow hash keys with leading underscores
+    $Template::Stash::PRIVATE = undef;
 };
 
 get '/' => sub {
+    if (var('user') and var('user')->admin) {
+        if (schema('netdisco')->resultset('Device')->count == 0) {
+            var('nodevices' => true);
+        }
+    }
+
     template 'index';
 };
 
